#
# spec file for package kcm5-fcitx
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define		pkgname	kf5-kcm-fcitx
Name:           kcm5-fcitx
Version:        0.5.6
Release:        4.4
Summary:        KF5 control module for Fcitx
License:        GPL-2.0-or-later
Group:          System/I18n/Chinese
URL:            http://github.com/fcitx/kcm-fcitx
Source:         http://download.fcitx-im.org/kcm-fcitx/kcm-fcitx-%{version}.tar.xz
Source1:        input-keyboard.svg
Patch0:         fix-building-with-qt-5.12.patch
BuildRequires:  cmake
BuildRequires:  extra-cmake-modules
BuildRequires:  fcitx-devel
BuildRequires:  fcitx-qt5-devel
BuildRequires:  gcc-c++
BuildRequires:  hicolor-icon-theme
BuildRequires:  intltool
BuildRequires:  kcmutils-devel
BuildRequires:  kcoreaddons-devel
BuildRequires:  ki18n-devel
BuildRequires:  kio-devel
BuildRequires:  kitemviews-devel
BuildRequires:  knewstuff-devel
BuildRequires:  kwidgetsaddons-devel
BuildRequires:  libqt5-qtbase-devel
BuildRequires:  libqt5-qtx11extras-devel
BuildRequires:  libtool
%if 0%{suse_version} >= 1550 || 0%{?sle_version} >= 150200
BuildRequires:  rsvg-convert
%else
BuildRequires:  rsvg-view
%endif
BuildRequires:  xz
BuildRequires:  pkgconfig(xkbfile)
Requires:       fcitx-kcm-icons
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
KF5 control module for Fcitx.

You can config fcitx through "Configue Desktop" - "Locale" - Fcitx now.

%package -n %{pkgname}
Summary:        KF5 control module for Fcitx
Group:          System/I18n/Chinese
Requires:       fcitx-qt5
Requires:       plasma5-workspace
Supplements:    packageand(fcitx:plasma5-workspace)
Provides:       locale(plasma5-workspace:ko;zh_CN;zh_SG)
# for better user experience
Provides:       fcitx-config-kde5 = %{version}
Provides:       fcitx-config-kf5 = %{version}
Obsoletes:      fcitx-config-kde5 < %{version}
%{fcitx_requires}

%description -n %{pkgname}
KF5 control module for Fcitx.

You can config fcitx through "Configure Desktop" - "Locale" - Fcitx now.

%package -n %{pkgname}-icons
Summary:        Keyboard icons for %{pkgname}
Group:          System/I18n/Chinese
Requires:       %{pkgname} = %{version}
Supplements:    packageand(%{pkgname}:plasma5-workspace-branding-openSUSE)
Conflicts:      otherproviders(fcitx-kcm-icons)
Provides:       fcitx-config-kde5-icons = %{version}
Obsoletes:      fcitx-config-kde5-icons < %{version}
Provides:       fcitx-kcm-icons = %{version}
BuildArch:      noarch

%description -n %{pkgname}-icons
This package provides systemsettings5 icons for fcitx in plasma5-workspace.

%prep
%autosetup -p1 -n kcm-fcitx-%{version}

%build
%cmake_kf5 -d build
make %{?_smp_mflags}

%install
pushd build
%kf5_makeinstall
popd

ICONSIZE="16 22 32 48 64 128 256"
for i in $ICONSIZE; do
    mkdir -pv %{buildroot}%{_datadir}/icons/hicolor/${i}x${i}/devices/
    rsvg-convert -h $i -w $i %{SOURCE1} -o %{buildroot}%{_datadir}/icons/hicolor/${i}x${i}/devices/input-keyboard.png
done

%find_lang kcm_fcitx

%{kf5_post_install}

%post -n %{pkgname} -p /sbin/ldconfig
%postun -n %{pkgname} -p /sbin/ldconfig

%files -n %{pkgname} -f kcm_fcitx.lang
%defattr(-,root,root,-)
%{_bindir}/kbd-layout-viewer
%{_libdir}/qt5/plugins/kcm_fcitx.so
%{_datadir}/kservices5/kcm_fcitx.desktop
%{_datadir}/applications/kbd-layout-viewer.desktop

%files -n %{pkgname}-icons
%defattr(-,root,root,-)
%{_datadir}/icons/hicolor/*/devices/input-keyboard.png

%changelog
* Thu Feb 22 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%autosetup macro. Allows to eliminate the usage of deprecated
  %%patchN
* Fri Dec 11 2020 Marguerite Su <i@marguerite.su>
- fix-building-with-qt-5.12.patch does not work as it said, it should
  detect Qt version by itself
* Wed Dec  9 2020 Antonio Larrosa <alarrosa@suse.com>
- Add patch to build with Qt 5.12 which doesn't have
  QList::swapItemsAt. The patch is only applied if Qt < 5.13 is being
  used to build the package.
  * fix-building-with-qt-5.12.patch
* Mon Sep 28 2020 Marguerite Su <i@marguerite.su>
- update version 0.5.6
  * [kcm] try qt5 wrapper before qt4
  * [kcm] use non neg value as role
- drop kcm5-fcitx-po.patch, no more kcm-fcitx
* Thu Feb 20 2020 Max Lin <mlin@suse.com>
- Leap 15.2 and SLE15 SP2 has newer librsvg, extend the conditional
  for "BuildRequires: rsvg-convert"
* Wed Oct 23 2019 ro@suse.de
- fix build-requires for factory/tumbleweed
  rsvg-convert tool is now in rsvg-convert package
* Mon Mar 12 2018 werner@suse.de
- Repair next removed dependency, that is add build require
  pkgconfig(xkbfile)
* Sat Dec  2 2017 i@marguerite.su
- update version 0.5.5
  * try qt5 wrapper before qt4
  * Use the correct dependency
  * try best to fit text in the rect
  * we don't listen to xkb event, why we would wother request it
  * revive the layout viewer
* Sun Aug 20 2017 zaitor@opensuse.org
- Drop conditional libunique-devel and libunique1-devel
  BuildRequires: Obsolete and unused.
* Sat Feb 11 2017 i@marguerite.su
- update version 0.5.4
  * use gui wrapper instead of embed.
* Wed Dec 23 2015 i@marguerite.su
- update version 0.5.3
  * revert to QTreeView implementation, KCategorizedView is buggy
  * blindly make use of iso_639 for translation, fcitx uses it
    anyway.
- drop patch: 0001-kcm-revert-to-QTreeView-implementation-KCategorizedV.patch
  upstreamed
* Fri Dec 18 2015 tiwai@suse.de
- Upstream fix for converting to QTreeView instead of broken
  KCategorizedView; this fixes the still-existing crash at clicking
  "Only Show Currnet Language" checkbox:
    0001-kcm-revert-to-QTreeView-implementation-KCategorizedV.patch
  obsoleting the old patch
    kcm-fcitx-workaround-for-invalid-langcode.patch
* Thu Oct 22 2015 tiwai@suse.de
- Work around a crash at clicking "Only Show Current Language"
  (boo#951609):
  kcm-fcitx-workaround-for-invalid-langcode.patch
* Sun Oct 18 2015 i@marguerite.su
- update version 0.5.2
  * A small bugfix relaese.
  * Fixes some wrong dialog layout when porting to Qt5/KF5.
- changes in 0.5.1
  * Fix some dialog handling
  * Make kcm layout uniform w/ other kcms in system settings
- rename fcitx-config-kde5 to kf5-kcm-fcitx
* Wed Jun 10 2015 i@marguerite.su
- don't rely on specific kf5 version
* Thu Apr  2 2015 i@marguerite.su
- package forked from kcm-fcitx
- update version 0.5.0: first version w/ kf5 support.
- add patch: kcm5-fcitx-po.patch
  * rename po to kcm5_fcitx to avoid conflict w/ kcm_fcitx
- update macros used in specfile to kf5 alternatives.
- split a new subpackage: fcitx-config-kde5-icons
  * avoid file conflicts when fcitx-config-kde4 is also installed
  * icons may be different later, but for now they're the same
* Mon Jul  1 2013 i@marguerite.su
- update version 0.4.3
  * Use new fcitx-qt widget to grab modifier only key.
  * Translation Update
* Sat Jan 26 2013 i@marguerite.su
- update version 0.4.2
  * Add support for new custom configuration ui.
- kcm-fcitx-0.4.2-compat-qt474.patch
  * fix build with qt 4.7.4 under 12.1 and below.
  * remove next release
* Sat Sep 15 2012 i@marguerite.su
- update version 0.4.1
  * Add support for hidden options
  * Simplify access to current UI setting
* Sat Jul 21 2012 i@marguerite.su
- update version 0.4.0
  * new implementation for key conversion
  * add support for change “default layout”
* Mon Jun 25 2012 i@marguerite.su
- fix fedora builds.
* Thu Jun  7 2012 i@marguerite.su
- remove fix shebang line from spec file.
  * now it has no shebang, this will remove good code
    thus cause no configuration page under system settings - locale.
* Mon Jun  4 2012 i@marguerite.su
- update version 0.3.4
  * configure input method from input method page
* Mon May 28 2012 i@marguerite.su
- bring it into DVD.
* Sun May  6 2012 i@marguerite.su
- update to 0.3.3
  * add super support
  * workaround a potential freeze bug
* Sun Apr  8 2012 i@marguerite.su
- update to 0.3.2
  * Add more X key to Qt key conversion.
* Fri Mar  9 2012 hillwood@linuxfans.org
- update to 0.3.1
  sync with head
* Wed Feb 29 2012 i@marguerite.su
- set _service disabled. update source from git.
* Thu Jan 26 2012 i@marguerite.su
- fix shebang warning
* Thu Jan 26 2012 i@marguerite.su
- update source from git. version 0.4.0
* Mon Oct  3 2011 stecue@gmail.com
- Change the package name to fcitx-config-kde4 to avoid
  confusing.
* Sun Oct  2 2011 stecue@gmail.com
- upstream version 0.2.1
  * works with fcitx-4.1.2
* Fri Sep  9 2011 stecue@gmail.com
- Initial build. Version 0.1.1
